darkhistory.electrons.ics.nonrel_diff_terms — DarkHistory documentation

# darkhistory.electrons.ics.nonrel_diff_terms

Functions for computing the nonrelativistic ICS spectrum by beta expansion.

Functions

`H_and_G`(beta, photeng, T[, as_pairs]) | Computes the H and G term.
`Q`(beta, photeng, T[, as_pairs]) | Computes the Q term.
`Q_and_K`(beta, photeng, T[, as_pairs]) | Computes the Q and K term.
`diff_expansion`(beta, photeng, T[, as_pairs]) | Computes the expansion for small beta and photeng/T.

#### Previous topic

darkhistory.electrons.ics.ics_spectrum.rel_spec

#### Next topic

darkhistory.electrons.ics.nonrel_diff_terms.H_and_G

### This Page

Show Source